@@ -156,7 +156,7 @@ def getLazyLocalTranslate(translateFunc):
     return Translate
 
 
-class RegexpLocalization(object):
+class RegexpLocalization():
     def __init__(self, domain, languages=(Lang.get_current_lang())):
         try:
             self.set_translate_dict(Catalog(domain,
@@ -171,9 +171,11 @@ class RegexpLocalization(object):
             except re.error:
                 return None
 
-        self._catalog = filter(lambda x: x[0],
-                               ((create_key(k), v) for k, v in
-                                sorted(d.items(), reverse=True) if k))
+        # self._catalog = list(filter(lambda x: x[0],
+        #                        ((create_key(k), v) for k, v in
+        #                         sorted(d.items(), reverse=True) if k)))
+        self._catalog = [x for x in [(create_key(k), v) for k, v in
+                                sorted(d.items(), reverse=True) if k] if x[0]]
 
     def translate(self, s):
         for k, v in self._catalog:
