@@ -23,8 +23,13 @@ from copy import deepcopy
 #     ET._Element.append(*args, **kwargs)
 
 def display_xml(xml):
-    print(str(ET.tostring(xml, pretty_print=True), encoding="UTF-8"))
+    print(xml_to_str(xml))
 
+def xml_to_str(xml):
+    return str(ET.tostring(xml, pretty_print=True), encoding="UTF-8")
+
+def str_to_xml_doc(text):
+    return ET.XML(bytes(bytearray(text, encoding="UTF-8")))
 
 #backwards compat
 class xpath():
@@ -221,7 +226,7 @@ class xmlDoc():
         # self.root = self.doc.documentElement
         # self.body = xpath.Evaluate('child::body', self.root)[0]
         
-        self.doc = ET.XML(bytes(bytearray(docTxt, encoding='utf-8')))
+        self.doc = str_to_xml_doc(docTxt)
         self.root = self.doc
         self.body = xpath.Evaluate('child::body', self.root)[0]
         # установка разделителя областей
@@ -587,7 +592,7 @@ class xmlDoc():
         areaNodes = xpath.Evaluate('descendant::area', xmlArea)
         for areaNode in areaNodes:
             prevNode = areaNode.getprevious()
-            if prevNode:
+            if prevNode is not None:
                 parentNode = areaNode.getparent()
                 insertBefore(parentNode, deepcopy(self.sepAreas),
                                         areaNode)
