@@ -14,18 +14,19 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from __future__ import print_function
-from __future__ import absolute_import
+
+
 import re
 import sys
 import importlib
-from calculate.lib.utils.tools import drop_slash
+from .utils.tools import drop_slash
 from .utils.text import convertStrListDict, _u, _u8, formatListOr
 from .utils.files import pathJoin
 from .utils.portage import searchProfile, RepositorySubstituting, RepositoryPath
 from os import path
 import os
-from collections import OrderedDict, Iterable
+from collections import OrderedDict
+from collections.abc import Iterable
 from threading import RLock
 from itertools import *
 import operator
@@ -34,9 +35,9 @@ from string import Formatter
 from contextlib import contextmanager
 # from types import StringTypes, GeneratorType
 from types import GeneratorType
-from calculate.lib.configparser import ConfigParser, ParsingError
+from .configparser import ConfigParser, ParsingError
 
-from calculate.lib.cl_lang import setLocalTranslate, getLazyLocalTranslate
+from .cl_lang import setLocalTranslate, getLazyLocalTranslate
 
 _ = lambda x: x
 setLocalTranslate('cl_lib3', sys.modules[__name__])
@@ -95,7 +96,7 @@ READONLY = "r"
 WRITEABLE = "w"
 
 
-class HumanReadable(object):
+class HumanReadable():
     Yes = True
     No = False
     Auto = None
@@ -111,7 +112,7 @@ class ValueFormatter(Formatter):
         return Get(field_name), None
 
 
-class VariableInterface(object):
+class VariableInterface():
     _value_formatter = ValueFormatter()
     type = "string"
 
@@ -171,7 +172,7 @@ class Variable(VariableInterface):
         section of variable (main,install,builder and etc)
     """
 
-    class Types(object):
+    class Types():
         String = "string"
         List = "list"
         Choice = "choice"
@@ -293,11 +294,14 @@ class Variable(VariableInterface):
         """Get value of other value"""
         if not varname or varname == self.name:
             return self._get()
-
+        
         varObj = self.parent.getInfo(varname)
+        
         # varObj.modeGet = Variable.UNCOMPAT
         if not "." in varname:
-            varname = "%s.%s" % (self.section, varname)
+            # varname = "%s.%s" % tuple([self.section, varname])
+            varname = f"{self.section}.{varname}"
+        
         res = self.parent.Get(varname, humanreadable)
 
         # build dependence for check and uncompatible
@@ -334,10 +338,9 @@ class Variable(VariableInterface):
         """
         if "humanreadable" in kw:
             hr = kw['humanreadable']
-            return zip(*map(lambda x:self.Get(x, humanreadable=hr),
-                            argvVarNames))
+            return list(zip(*(self.Get(x, humanreadable=hr) for x in argvVarNames)))
         else:
-            return zip(*map(self.Get, argvVarNames))
+            return list(zip(*map(self.Get, argvVarNames)))
 
     def _get_format_value(self):
         return self._value_formatter.format(
@@ -395,8 +398,9 @@ class Variable(VariableInterface):
         self.bIniRead = True
         try:
             value = self.parent.iniCache[self.fullname]
-            value = self.parent.unserialize(self.type,
-                                            value.encode('utf-8'))
+            value = self.parent.unserialize(self.type, value)
+            # value = self.parent.unserialize(self.type,
+                                            # value.encode('utf-8'))
             if self.mode == READONLY:
                 raise VariableError(
                     _("Attempting to rewrite readonly variable %s "
@@ -441,7 +445,13 @@ class Variable(VariableInterface):
             if hasattr(self.value, "close"):
                 self.value.close()
             self.value = value
-        return self.value
+        # return self.value
+        val = self.value
+        
+        if isinstance(val, bytes):
+            val = str(val, encoding="UTF-8")
+
+        return val
 
     def choice(self):
         """
@@ -459,7 +469,7 @@ class Variable(VariableInterface):
         if isinstance(res, GeneratorType):
             res = tuple(res)
         if res and type(res[0]) in (tuple, list):
-            return zip(*res)
+            return list(zip(*res))
         else:
             return res, None
 
@@ -518,7 +528,7 @@ class Variable(VariableInterface):
         if self.type == "bool":
             value = "on" if self.isTrue(value) else "off"
         if "bool" in self.type and "list" in self.type:
-            return map(convert, value)
+            return [convert(x) for x in value]
         if "int" in self.type:
             return str(value)
         return value
@@ -551,7 +561,7 @@ class Variable(VariableInterface):
                 "The value for variable '{varname}' may be {vartype} only")
         if "string" in self.type:
             value, valuecopy = tee(value, 2)
-            if any(x for x in valuecopy if not type(x) in (str, unicode)):
+            if any(x for x in valuecopy if not isinstance(x, str)):
                 raise VariableError(error.format(
                     varname=self.label or self.name,
                     vartype="string"))
@@ -561,8 +571,7 @@ class Variable(VariableInterface):
             if isinstance(choiceVal, GeneratorType):
                 choiceVal = tuple(choiceVal)
 
-            tipChoice = map(lambda x: '"%s" [%s]' % (x[1], x[0]) \
-                if type(x) in (list, tuple) else str(x), choiceVal)
+            tipChoice = ['"%s" [%s]' % (x[1], x[0]) if type(x) in (list, tuple) else str(x) for x in choiceVal]
             if choiceVal and type(choiceVal[0]) in (tuple, list):
                 choiceVal = [x[0] for x in choiceVal]
         if "list-list" not in self.type:
@@ -681,7 +690,7 @@ class Variable(VariableInterface):
         """
         Проверить не изменился ли метод после наследования
         """
-        base_method = getattr(Variable, methodname).__func__
+        base_method = getattr(Variable, methodname)
         method = getattr(self, methodname).__func__
         return base_method == method
 
@@ -697,15 +706,11 @@ class TableVariable(Variable):
 
     def get(self, hr=HumanReadable.No):
         """Get table data"""
-        for varname, value in filter(lambda x: type(x[1]) != list,
-                                      map(lambda x: (x, self.Get(x)),
-                                           self.source)):
+        for varname, value in (x for x in ((y, self.Get(y)) for y in self.source) if not isinstance(x[1], list)):
             raise VariableError(
                 _("Source variable %s does not contain a list") % varname)
-        return map(list,
-                   zip_longest(
-                       *map(lambda x: self.Get(x, humanreadable=hr),
-                            self.source), fillvalue='')) or [[]]
+        return [list(x) for x in zip_longest(*[self.Get(x, humanreadable=hr) 
+            for x in self.source], fillvalue='')] or [[]]
 
     def getHumanReadableAuto(self):
         """
@@ -725,8 +730,9 @@ class TableVariable(Variable):
             offset = 0
         else:
             offset = 1
-        return filter(lambda x: self.parent.getInfo(x[1]).mode == WRITEABLE,
-                      enumerate(self.source[offset:]))
+        # return list(filter(lambda x: self.parent.getInfo(x[1]).mode == WRITEABLE,
+        #               enumerate(self.source[offset:])))
+        return [x for x in enumerate(self.source[offset:]) if self.parent.getInfo(x[1]).mode == WRITEABLE]
 
     def check(self, value):
         """
@@ -737,11 +743,9 @@ class TableVariable(Variable):
         if not any(value):
             value = [[]] * len(writeCols)
         else:
-            value = zip(*map(itemgetter(*map(itemgetter(0),
-                                             writeCols), alwaysTuple=True),
-                             value))
-        for colInfo, values in \
-                zip(writeCols, value):
+            value = list(zip(*map(itemgetter(*map(itemgetter(0),
+                writeCols), alwaysTuple=True),value)))
+        for colInfo, values in zip(writeCols, value):
             try:
                 self.parent.Check(colInfo[1], values)
             except VariableError as e:
@@ -803,34 +807,38 @@ class TableVariable(Variable):
         # create dict for writable columns
         # if table not empty
         if any(oldvalue):
-            oldvalue = OrderedDict(map(lambda x: (x[0], _slice(x[1:])),
-                                       oldvalue))
+            # oldvalue = OrderedDict(map(lambda x: (x[0], _slice(x[1:])),
+            #                            oldvalue))
+            oldvalue = OrderedDict([(x[0], _slice(x[1:])) for x in oldvalue])
         else:
             oldvalue = OrderedDict()
         # get new dict
         if any(value):
             if len(value[0]) == len(self.source):
-                newval = OrderedDict(map(lambda x: (x[0], _slice(x[1:])),
-                                         value))
+                # newval = OrderedDict(map(lambda x: (x[0], _slice(x[1:])),
+                #                          value))
+                newval = OrderedDict([(x[0], _slice(x[1:])) for x in value])
             else:
-                newval = OrderedDict(map(lambda x: (x[0], x[1:]), value))
+                # newval = OrderedDict(map(lambda x: (x[0], x[1:]), value))
+                newval = OrderedDict([(x[0], x[1:]) for x in value])
         else:
             newval = OrderedDict()
         # if table with writable index field then replace all table
         error = []
         if self.__isIndexWritable():
             if not force and any(value):
-                self.parent.Check(self.source[0], zip(*value)[0])
+                self.parent.Check(self.source[0], list(zip(*value))[0])
             oldvalue = newval
             try:
-                self.parent.Set(self.source[0], oldvalue.keys())
+                #py3 keys() now returns its own type instead of a list
+                self.parent.Set(self.source[0], list(oldvalue.keys()))
             except VariableError as e:
                 error.append(e)
         # update entry by index field
         else:
             oldvalue.update(newval)
-        oldvalValues = zip(*oldvalue.values())
-        for col, vals in zip(map(lambda x: x[1], writeCols),
+        oldvalValues = list(zip(*oldvalue.values()))
+        for col, vals in zip((x[1] for x in writeCols),
                              oldvalValues):
             try:
                 self.parent.Set(col, list(vals))
@@ -879,7 +887,7 @@ class FieldValue(VariableInterface):
         sourceVar = self.Get(self.source_variable)
         if isinstance(sourceVar, Iterable):
             if any(sourceVar):
-                return zip(*sourceVar)[self.column]
+                return list(zip(*sourceVar))[self.column]
             else:
                 return []
         else:
@@ -896,14 +904,12 @@ class SourceReadonlyVariable(ReadonlyVariable):
     indexField = ""
 
     def get(self):
-        return map(lambda x: x or "",
-                   map(self.getMap().get,
-                       self.Get(self.indexField)))
+        return [x or "" for x in map(self.getMap().get, 
+            self.Get(self.indexField))]
 
     def humanReadable(self):
-        return map(lambda x: x or "",
-                   map(self.getMapHumanReadable().get,
-                       self.Get(self.indexField)))
+        return [x or "" for x in map(self.getMapHumanReadable().get,
+            self.Get(self.indexField))]
 
     def getMap(self):
         return {}
@@ -919,7 +925,7 @@ class ReadonlyTableVariable(TableVariable):
     mode = READONLY
 
 
-class SimpleDataVars(object):
+class SimpleDataVars():
     """
     Simple datavars for temporary link var objs.
     """
@@ -1012,7 +1018,8 @@ class SimpleDataVars(object):
             if varname not in self.changed:
                 val = self.unserialize(
                     varobj.type or "string",
-                    importVars[varobj.section].get(varname, '').encode('utf-8'))
+                    #TODO bin or string?
+                    importVars[varobj.section].get(varname, ''))
                 if val and val != [[]] or varname in importVars[varobj.section]:
                     self.cache[varname] = val
 
@@ -1028,8 +1035,7 @@ class SimpleDataVars(object):
             if "list" in varType:
                 return ",".join(map(fixEmpty, value))
             elif "table" in varType:
-                return ",".join(map(lambda x: ":".join(map(fixEmpty, x)),
-                                    value))
+                return ",".join((":".join(map(fixEmpty, x)) for x in value))
         return fixEmpty(value)
 
     @staticmethod
@@ -1041,17 +1047,19 @@ class SimpleDataVars(object):
 
         def getList(delimeter=','):
             def wrapper(val):
+                val = str(val)
                 if val == "":
                     return []
-                return map(fixEmpty, val.split(delimeter))
+                return [fixEmpty(x) for x in val.split(delimeter)]
 
             return wrapper
 
         if "list" in varType:
             return getList()(value)
         if "table" in varType:
-            return map(getList(':'), value.split(','))
-        value = str(value, "UTF-8")
+            return [getList(':')(x) for x in value.split(',')]
+        # if (isinstance(value, bytes)):
+        #     value = str(value, "UTF-8")
         return fixEmpty(value).strip("'").strip('"')
 
     def ZipVars(self, *argvVarNames, **kw):
@@ -1060,10 +1068,9 @@ class SimpleDataVars(object):
         """
         if "humanreadable" in kw:
             hr = kw['humanreadable']
-            return zip(*map(lambda x:self.Get(x, humanreadable=hr),
-                            argvVarNames))
+            return list(zip(*(self.Get(x, humanreadable=hr) for x in argvVarNames)))
         else:
-            return zip(*map(self.Get, argvVarNames))
+            return list(zip(*(self.Get(x) for x in argvVarNames)))
 
     def select(self, *fields, **kw):
         """
@@ -1157,17 +1164,16 @@ class SimpleDataVars(object):
         if not type(where) in (tuple, list):
             where = [where]
         woffset = len(where)
+
         if isinstance(selField, (tuple, list)):
             count = len(selField) + woffset
             mapFunc = lambda x: x[woffset:]
-            res = filter(filterFunc,
-                         zipVars(*(where + selField)))
+            res = [x for x in zipVars(*(where + selField)) if filterFunc(x)]             
         else:
             count = 1 + woffset
             fields = where + [selField]
             mapFunc = lambda x: x[woffset]
-            res = filter(filterFunc,
-                         zipVars(*fields))
+            res = [x for x in zipVars(*(fields)) if filterFunc(x)]  
         if sort:
             if "/" in sort:
                 sort, sortkey = sort.split('/')
@@ -1178,7 +1184,7 @@ class SimpleDataVars(object):
                 res = [[""] * count]
             return mapFunc(res[0])
         else:
-            return map(mapFunc, res[:limit])
+            return [mapFunc(x) for x in res[:limit]]
 
 
 class DataVars(SimpleDataVars):
@@ -1201,7 +1207,7 @@ class DataVars(SimpleDataVars):
     l = RLock()
 
     def __init__(self):
-        super(DataVars, self).__init__()
+        super().__init__()
         self.requestVariables = []
         self.loadVariables = {}
         self.allVars = {}
@@ -1252,7 +1258,7 @@ class DataVars(SimpleDataVars):
         try:
             varModule = importlib.import_module(data)
         except (ImportError, AttributeError) as e:
-            self.raiseModuleError(data, e)
+            self.raiseModuleError(data, e) 
             return False
         # get all Variable classes from module
         # variable of class VariableClAction will be named cl_action
@@ -1260,15 +1266,12 @@ class DataVars(SimpleDataVars):
             section = varModule.section
         else:
             section = "main"
-        for varMod in list(map(lambda x: getattr(varModule, x),
-                          filter(lambda x: (not x.startswith("_") and
-                                                    "Variable" not in x),
-                                 dir(varModule)))) + [varModule]:
+        for varMod in [getattr(varModule, x) for x in dir(varModule) 
+            if not x.startswith("_") and "Variable" not in x] + [varModule]:
             for classname in filterfalse(
                     ("ReadonlyVariable", "VariableInterface",
                      "Variable", "VariableError").__contains__,
-                    filter(lambda x: x.startswith("Variable"),
-                            dir(varMod))):
+                    (x for x in dir(varMod) if x.startswith("Variable"))):
                 varObj = getattr(varMod, classname)
                 varName = varObj.getVariableName()
                 if not varName in self.allVars:
@@ -1350,7 +1353,7 @@ class DataVars(SimpleDataVars):
                     raise DataVarsError(_("Error in %s") % iniFile)
                 except KeyError:
                     pass
-        return retVal.encode('UTF-8')
+        return retVal
 
     def getRemoteInfo(self, envFile):
         """
@@ -1366,7 +1369,8 @@ class DataVars(SimpleDataVars):
         allsect = config.sections()
         for section in allsect:
             options = {
-                k.encode('utf-8'): convertStrListDict(v.encode('utf-8'))
+                # k.encode('utf-8'): convertStrListDict(v.encode('utf-8'))
+                k: convertStrListDict(v)
                 for k, v in config.items(section, raw=True)}
             if options:
                 optionsInfo[section] = options
@@ -1416,7 +1420,7 @@ class DataVars(SimpleDataVars):
                         continue
                     if onlySection:
                         iniSections = tuple(set(iniSections) &
-                                            {unicode(onlySection)})
+                                            {str(onlySection)})
                     for section in iniSections:
                         for key, value in config.items(section, raw=True):
                             key = _u8(key)
@@ -1428,11 +1432,14 @@ class DataVars(SimpleDataVars):
 
     def Get(self, varname, humanreadable=HumanReadable.No):
         """Threading safety Get"""
+        
         DataVars.l.acquire()
+        
         try:
             var = self.__Get(varname, humanreadable)
         finally:
             DataVars.l.release()
+        
         return var
 
     def isFromIni(self, varname):
@@ -1445,6 +1452,7 @@ class DataVars(SimpleDataVars):
 
     def splitVarname(self, varname):
         res = self.reRightVar.search(varname)
+            
         if res:
             if res.group(1):
                 return res.groups()
@@ -1460,7 +1468,10 @@ class DataVars(SimpleDataVars):
         try:
             # tm = time.time()
             # load variable if it isn't loaded
+            # if varname in ["install.os_lvm_data"]:
+            #     print("DEBUG in __GET")
             section, varname = self.splitVarname(varname)
+            
             if (varname not in self.loadVariables or
                         section not in self.importedModules):
                 try:
@@ -1470,16 +1481,16 @@ class DataVars(SimpleDataVars):
                         return ""
                     raise
             varObj = self.loadVariables[varname]
-
+            
             # check section
             if varObj.section not in (section, "main"):
                 self.raiseVariableNotFound(varname, parent=self,
                                            section=section)
-
+            # if varname in ["os_lvm_data"]:
+            #     print("DEBUG2 in __GET")
             # if for this variable already use Get method
             if varObj.invalid and varObj in self.requestVariables:
-                varnames = "-".join(map(lambda x: x.name,
-                                        self.requestVariables + [varObj]))
+                varnames = "-".join((x.name for x in self.requestVariables + [varObj]))
                 raise DataVarsError(
                     _("Loop dependence of variables '%s'") % varnames)
             # add this variable for list of requested variables
@@ -1812,18 +1823,18 @@ class DataVars(SimpleDataVars):
         Fix data get by wsdl (list-list) type
         """
         if varObj.type == "table":
-            multiLists = filter(lambda x: "list-list" in x[1],
-                                enumerate(
-                                    [self.getInfo(x).type for x in
-                                     varObj.source]))
+            # multiLists = list(filter(lambda x: "list-list" in x[1],
+            #                     enumerate(
+            #                         [self.getInfo(x).type for x in
+            #                          varObj.source])))
+            multiLists = [x for x in enumerate([self.getInfo(x).type for x in varObj.source]) if "list-list" in x[1]]
             if multiLists:
                 val = list(zip_longest(*val, fillvalue=""))
                 for col, typecol in multiLists:
                     if col < len(val):
-                        val[col] = map(
-                            lambda x: x.split(',')
-                            if type(x) in (str) else x,
-                            val[col])
+                        val[col] = [x.split(',') 
+                            if isinstance(x, str) else x for x 
+                            in val[col]]
                 val = list(zip_longest(*val, fillvalue=""))
         return val
 
@@ -1843,8 +1854,8 @@ class DataVars(SimpleDataVars):
         Вывести группу переменных
         """
         print("=DEBUG.SET=")
-        for vname in sorted(filter(lambda x: x.lower() == x,
-                                   info._type_info.keys())):
+        for vname in sorted((x for x 
+                in info._type_info.keys() if x.lower() == x)):
             print("|", vname, "=", getattr(info, vname))
         print("=DEBUG.DATAVARS=")
         for vname in self.mapVarGroup.keys():
@@ -1857,9 +1868,8 @@ class DataVars(SimpleDataVars):
         """
 
         def compare_choice(part_s, *options):
-            lower_unicode = lambda x: _u(x).lower()
-            part_s = lower_unicode(part_s)
-            options = [lower_unicode(x) for x in options]
+            part_s = part_s.lower()
+            options = [x.lower() for x in options]
             return any(x == part_s for x in options)
 
         def get_val_from_choice(choicedata, val):
@@ -1867,14 +1877,13 @@ class DataVars(SimpleDataVars):
             Получить похожее значение
             """
             if val not in [x[0] for x in choicedata]:
-                result = filter(lambda x: compare_choice(val, x[0], x[1]),
-                                choicedata)
+                # result = list(filter(lambda x: compare_choice(val, x[0], x[1]),
+                #                 choicedata))
+                result = [x for x in choicedata if compare_choice(val, x[0], x[1])]
                 if len(result) > 1:
                     raise VariableError(
-                        _("Ambiguous choice:%s") % formatListOr(map(
-                            lambda x: ('"%s"(%s)' % (x[1], x[0])
-                                       if x[0] != x[1] else x[0]),
-                            result)))
+                        _("Ambiguous choice:%s") % formatListOr((('"%s"(%s)' % (x[1], x[0])
+                            if x[0] != x[1] else x[0]) for x in result)))
                 elif result:
                     return result[0][0]
             return val
@@ -1883,11 +1892,10 @@ class DataVars(SimpleDataVars):
             return []
         errors = []
         if self.groups:
-            keys = self.mapVarGroup.keys()
+            keys = list(self.mapVarGroup.keys())
         else:
-            keys = sorted(filter(lambda x: x.lower() == x,
-                                 info._type_info.keys()))
-        varsByKeys = map(self.getInfo, keys)
+            keys = sorted((x for x in info._type_info.keys() if x.lower() == x))
+        varsByKeys = [self.getInfo(x) for x in keys]
         groupVars = []
 
         # invalidate default variables
@@ -1920,8 +1928,8 @@ class DataVars(SimpleDataVars):
                     continue
                 # get value of variable from info
                 val = getattr(info, var)
-                if type(val) == unicode:
-                    val = _u8(val)
+                # if type(val) == unicode:
+                #     val = _u8(val)
             varSendFromClient = val is not None and var not in default
             varGroupUntrusted = varObj.untrusted and var in groupVars
             varAllUntrusted = varObj.untrusted and allvars
@@ -1949,7 +1957,7 @@ class DataVars(SimpleDataVars):
                                 if choicedata[1] is None:
                                     choicedata = [choicedata[0],
                                                   choicedata[0]]
-                                choicedata = zip(*choicedata)
+                                choicedata = list(zip(*choicedata))
                                 if varObj.type == "choice":
                                     vals = [val]
                                 else:
@@ -1968,16 +1976,15 @@ class DataVars(SimpleDataVars):
                             raise VariableError(uncomperr)
                 except (VariableError, DataVarsError) as e:
                     # assemble all variable errors
-                    messages = e.message if type(e.message) == list \
+                    messages = e if type(e) == list \
                         else [e]
-                    mess = "\n".join(
-                        map(lambda x: str(x), self.plainList(*messages)))
+                    mess = "\n".join((str(x) for x in messages))
                     mapError = {PasswordError: 'pwderror',
                                 CommonVariableError: 'commonerror'}
                     for k, v in mapError.items():
-                        if (isinstance(e, k) or type(e.message) == list and
+                        if (isinstance(e, k) or type(e) == list and
                             all(isinstance(x, k) for x in
-                                e.message)):
+                                e)):
                             typeError = v
                             break
                     else:
@@ -2011,6 +2018,6 @@ class DataVars(SimpleDataVars):
 
     def printWrong(self, filt=lambda x: x):
         print("!!!WRONG VARS!!!")
-        for i in sorted(filter(filt, self.allVars.keys())):
+        for i in sorted((x for x in self.allVars.keys() if filt(x))):
             if self.getInfo(i).untrusted:
                 print("{0:<40} {1}".format(i, self.Get(i, True)))
